@@ -32,19 +32,19 @@ class MeteoRawMessage(Message):
         self.needs_no_rtr(rtr)
         self.needs_data(data, 6)
         self.set_attributes(priority, address, rtr)
-        self.rain = (((data[0] << 8)| data[1]) / 32 ) * 0.1
-        self.light = (((data[2] << 8) | data[3]) / 32 )
-        self.wind = (((data[4] << 8) | data[5]) / 32 ) * 0.1
+        self.rain = (((data[0] << 8) | data[1]) / 32) * 0.1
+        self.light = ((data[2] << 8) | data[3]) / 32
+        self.wind = (((data[4] << 8) | data[5]) / 32) * 0.1
 
     def to_json(self):
         """
         :return: str
         """
         json_dict = self.to_json_basic()
-        json_dict['rain'] = self.rain
-        json_dict['light'] = self.light
-        json_dict['wind'] = self.wind
+        json_dict["rain"] = self.rain
+        json_dict["light"] = self.light
+        json_dict["wind"] = self.wind
         return json.dumps(json_dict)
 
 
-register_command(COMMAND_CODE, MeteoRawMessage, 'VMBMETEO')
+register_command(COMMAND_CODE, MeteoRawMessage, "VMBMETEO")
