@@ -5,7 +5,7 @@ import json
 from velbus.message import Message
 from velbus.command_registry import register_command
 
-COMMAND_CODE = 0xe6
+COMMAND_CODE = 0xE6
 
 
 class SensorTemperatureMessage(Message):
@@ -35,18 +35,18 @@ class SensorTemperatureMessage(Message):
         self.needs_no_rtr(rtr)
         self.needs_data(data, 6)
         self.set_attributes(priority, address, rtr)
-        self.cur = (((data[0] << 8)| data[1]) / 32 ) * 0.0625
-        self.min = (((data[2] << 8) | data[3]) / 32 ) * 0.0625
-        self.max = (((data[4] << 8) | data[5]) / 32 ) * 0.0625
+        self.cur = (((data[0] << 8) | data[1]) / 32) * 0.0625
+        self.min = (((data[2] << 8) | data[3]) / 32) * 0.0625
+        self.max = (((data[4] << 8) | data[5]) / 32) * 0.0625
 
     def to_json(self):
         """
         :return: str
         """
         json_dict = self.to_json_basic()
-        json_dict['cur'] = self.cur
-        json_dict['min'] = self.min
-        json_dict['max'] = self.max
+        json_dict["cur"] = self.cur
+        json_dict["min"] = self.min
+        json_dict["max"] = self.max
         return json.dumps(json_dict)
 
 
