@@ -3,7 +3,8 @@
 """
 from velbus.message import Message
 from velbus.command_registry import register_command
-COMMAND_CODE = 0xf7
+
+COMMAND_CODE = 0xF7
 
 
 class SlowBlinkingLedMessage(Message):
@@ -32,10 +33,7 @@ class SlowBlinkingLedMessage(Message):
         """
         :return: bytes
         """
-        return bytes([
-            COMMAND_CODE,
-            self.channels_to_byte(self.leds)
-        ])
+        return bytes([COMMAND_CODE, self.channels_to_byte(self.leds)])
 
 
 register_command(COMMAND_CODE, SlowBlinkingLedMessage)
