@@ -6,7 +6,7 @@ import logging
 from velbus.message import Message
 from velbus.command_registry import register_command
 
-COMMAND_CODE = 0xdd
+COMMAND_CODE = 0xDD
 
 
 class SwitchToNightMessage(Message):
@@ -32,17 +32,14 @@ class SwitchToNightMessage(Message):
         :return: str
         """
         json_dict = self.to_json_basic()
-        json_dict['sleep_time'] = self.sleep
+        json_dict["sleep_time"] = self.sleep
         return json.dumps(json_dict)
 
     def data_to_binary(self):
         """
         :return: bytes
         """
-        return bytes([
-            COMMAND_CODE,
-            0x00,
-            0x00
-        ])
+        return bytes([COMMAND_CODE, 0x00, 0x00])
+
 
 register_command(COMMAND_CODE, SwitchToNightMessage)
