@@ -8,7 +8,13 @@ from velbus.modules.vmbgp import VMBGPxModule, VMBGPxDModule, VMBGPPirModule
 from velbus.modules.vmbpbn import VMB2PBNModule, VMB6PBNModule, VMB8PBUModule
 from velbus.modules.vmb1ts import VMB1TSModule
 from velbus.modules.vmbiro import VMBIROModule
-from velbus.modules.vmbbl import VMB1BLModule, VMB2BLModule, VMB1BLEModule, VMB2BLEModule
+from velbus.modules.vmbbl import (
+    VMB1BLModule,
+    VMB2BLModule,
+    VMB1BLEModule,
+    VMB2BLEModule,
+)
 from velbus.modules.vmbmeteo import VMBMETEOModule
 from velbus.modules.vmbdme import VMBDMEModule
 from velbus.modules.vmb4dc import VMB4DCModule
+from velbus.modules.vmbdmi import VMBDMIModule
