@@ -10,6 +10,7 @@ class VMB1TSModule(Module):
     """
     Velbus input module with 6 channels
     """
+
     def __init__(self, module_type, module_name, module_address, controller):
         Module.__init__(self, module_type, module_name, module_address, controller)
         self._cur = None
@@ -44,7 +45,7 @@ class VMB1TSModule(Module):
         self._callbacks.append(callback)
 
     def get_categories(self, channel):
-        return ['sensor']
+        return ["sensor"]
 
     def get_state(self, channel):
         """
@@ -56,13 +57,13 @@ class VMB1TSModule(Module):
         """
         Ignore channel
         """
-        return 'temperature'
+        return "temperature"
 
     def get_unit(self, channel):
         """
         Ignore channel
         """
-        return '°C'
+        return "°C"
 
 
-register_module('VMB1TS', VMB1TSModule)
+register_module("VMB1TS", VMB1TSModule)
