@@ -1,18 +1,21 @@
 import os
 from velbus.constants import MINIMUM_MESSAGE_SIZE, MAXIMUM_MESSAGE_SIZE
 
+
 def on_app_engine():
     """
     :return: bool
     """
-    if 'SERVER_SOFTWARE' in os.environ:
-        server_software = os.environ['SERVER_SOFTWARE']
-        if server_software.startswith('Google App Engine') or \
-                server_software.startswith('Development'):
+    if "SERVER_SOFTWARE" in os.environ:
+        server_software = os.environ["SERVER_SOFTWARE"]
+        if server_software.startswith(
+            "Google App Engine"
+        ) or server_software.startswith("Development"):
             return True
         return False
     return False
 
+
 def checksum(data):
     """
     :return: int
@@ -33,9 +36,10 @@ def checksum(data):
 
 class VelbusException(Exception):
     """Velbus Exception."""
+
     def __init__(self, value):
         Exception.__init__(self)
         self.value = value
 
     def __str__(self):
-        return repr(self.value)
\ No newline at end of file
+        return repr(self.value)
